# LAttice-based Speech Transducer (LAST)

[![Unittests](https://github.com/google-research/last/actions/workflows/pytest_and_autopublish.yml/badge.svg)](https://github.com/google-research/last/actions/workflows/pytest_and_autopublish.yml)
[![PyPI version](https://badge.fury.io/py/last-asr.svg)](https://badge.fury.io/py/last-asr)

*This is not an officially supported Google product.*

The LAttice-based Speech Transducer (LAST) is a JAX library for building
lattice-based speech transducer models, such as
[GNAT](https://arxiv.org/abs/2205.13674).

To start using LAST, simply run `pip install --upgrade last-asr`. For more
information, check out https://last-asr.readthedocs.io.
